=== modified file 'bzrlib/tests/test_transport_implementations.py'
--- bzrlib/tests/test_transport_implementations.py	2006-09-05 18:48:28 +0000
+++ bzrlib/tests/test_transport_implementations.py	2006-09-05 19:34:34 +0000
@@ -132,22 +132,29 @@
         t = self.get_transport()
 
         if t.is_readonly():
-            self.assertRaises(TransportNotPossible,
-                    t.put, 'a', StringIO('some text for a\n'))
-            return
-
-        t.put('a', StringIO('some text for a\n'))
-        self.failUnless(t.has('a'))
-        self.check_transport_contents('some text for a\n', t, 'a')
-        # Make sure 'has' is updated
-        self.assertEqual(list(t.has_multi(['a', 'b', 'c', 'd', 'e'])),
-                [True, False, False, False, False])
-        # Put also replaces contents
+            return
+
+        deprecation_msg = '%s.%s.%s was deprecated in version 0.11.' % (
+            t.put.im_class.__module__, t.put.im_class.__name__,
+            t.put.__name__)
+        self.callDeprecated([deprecation_msg],
+                            t.put, 'a', 'string\ncontents\n')
+        self.check_transport_contents('string\ncontents\n', t, 'a')
+
+        self.callDeprecated([deprecation_msg],
+                            t.put, 'b', StringIO('file-like\ncontents\n'))
+        self.check_transport_contents('file-like\ncontents\n', t, 'b')
+
+    def test_put_multi(self):
+        t = self.get_transport()
+
+        if t.is_readonly():
+            return
         self.assertEqual(t.put_multi([('a', StringIO('new\ncontents for\na\n')),
                                       ('d', StringIO('contents\nfor d\n'))]),
                          2)
-        self.assertEqual(list(t.has_multi(['a', 'b', 'c', 'd', 'e'])),
-                [True, False, False, True, False])
+        self.assertEqual(list(t.has_multi(['a', 'b', 'c', 'd'])),
+                [True, False, False, True])
         self.check_transport_contents('new\ncontents for\na\n', t, 'a')
         self.check_transport_contents('contents\nfor d\n', t, 'd')
 
@@ -158,6 +165,20 @@
         self.check_transport_contents('diff\ncontents for\na\n', t, 'a')
         self.check_transport_contents('another contents\nfor d\n', t, 'd')
 
+    def test_put_file(self):
+        t = self.get_transport()
+
+        if t.is_readonly():
+            self.assertRaises(TransportNotPossible,
+                    t.put_file, 'a', StringIO('some text for a\n'))
+            return
+
+        t.put_file('a', StringIO('some text for a\n'))
+        self.failUnless(t.has('a'))
+        self.check_transport_contents('some text for a\n', t, 'a')
+        # Put also replaces contents
+        t.put_file('a', StringIO('new\ncontents for\na\n'))
+        self.check_transport_contents('new\ncontents for\na\n', t, 'a')
         self.assertRaises(NoSuchFile,
                           t.put, 'path/doesnt/exist/c', StringIO('contents'))
 

=== modified file 'bzrlib/transport/__init__.py'
--- bzrlib/transport/__init__.py	2006-09-05 18:48:28 +0000
+++ bzrlib/transport/__init__.py	2006-09-05 19:34:34 +0000
@@ -39,15 +39,23 @@
 import warnings
 
 import bzrlib
-import bzrlib.errors as errors
+from bzrlib import (
+    errors,
+    osutils,
+    symbol_versioning,
+    urlutils,
+    )
 from bzrlib.errors import DependencyNotPresent
-import bzrlib.osutils as osutils
 from bzrlib.osutils import pumpfile
-from bzrlib.symbol_versioning import (deprecated_passed, deprecated_method, deprecated_function, 
+from bzrlib.symbol_versioning import (
+        deprecated_passed,
+        deprecated_method,
+        deprecated_function,
         DEPRECATED_PARAMETER,
-        zero_eight)
+        zero_eight,
+        zero_eleven,
+        )
 from bzrlib.trace import mutter, warning
-import bzrlib.urlutils as urlutils
 
 # {prefix: [transport_classes]}
 # Transports are inserted onto the list LIFO and tried in order; as a result
@@ -491,15 +499,37 @@
             yield self.get(relpath)
             count += 1
 
+    @deprecated_method(zero_eleven)
     def put(self, relpath, f, mode=None):
-        """Copy the file-like into the location.
+        """Copy the file-like or string object into the location.
 
         :param relpath: Location to put the contents, relative to base.
         :param f:       File-like or string object.
         :param mode: The mode for the newly created file, 
                      None means just use the default
         """
-        raise NotImplementedError(self.put)
+        if isinstance(f, str):
+            return self.put_bytes(relpath, f, mode=mode)
+        else:
+            return self.put_file(relpath, f, mode=mode)
+
+    def put_file(self, relpath, f, mode=None):
+        """Copy the file-like object into the location.
+
+        :param relpath: Location to put the contents, relative to base.
+        :param f:       File-like object.
+        :param mode: The mode for the newly created file,
+                     None means just use the default.
+        """
+        # We would like to mark this as NotImplemented, but most likely
+        # transports have defined it in terms of the old api.
+        symbol_versioning.warn('Transport %s should implement put_file,'
+                               ' rather than implementing put() as of'
+                               ' version 0.11.'
+                               % (self.__class__.__name__,),
+                               DeprecationWarning)
+        return self.put(relpath, f, mode=mode)
+        #raise NotImplementedError(self.put_file)
 
     def put_bytes(self, relpath, bytes, mode=None):
         """Atomically put the supplied bytes into the given location.
@@ -512,7 +542,7 @@
         """
         assert isinstance(bytes, str), \
             'bytes must be a plain string, not %s' % type(bytes)
-        return self.put(relpath, StringIO(bytes), mode=mode)
+        return self.put_file(relpath, StringIO(bytes), mode=mode)
 
     def put_multi(self, files, mode=None, pb=None):
         """Put a set of files into the location.

=== modified file 'bzrlib/transport/decorator.py'
--- bzrlib/transport/decorator.py	2006-07-28 16:05:23 +0000
+++ bzrlib/transport/decorator.py	2006-09-05 19:34:34 +0000
@@ -96,10 +96,14 @@
         """See Transport.mkdir()."""
         return self._decorated.mkdir(relpath, mode)
 
-    def put(self, relpath, f, mode=None):
-        """See Transport.put()."""
-        return self._decorated.put(relpath, f, mode)
+    def put_file(self, relpath, f, mode=None):
+        """See Transport.put_file()."""
+        return self._decorated.put_file(relpath, f, mode)
     
+    def put_bytes(self, relpath, bytes, mode=None):
+        """See Transport.put_bytes()."""
+        return self._decorated.put_bytes(relpath, bytes, mode)
+
     def listable(self):
         """See Transport.listable."""
         return self._decorated.listable()

=== modified file 'bzrlib/transport/fakevfat.py'
--- bzrlib/transport/fakevfat.py	2006-07-28 16:05:23 +0000
+++ bzrlib/transport/fakevfat.py	2006-09-05 19:34:34 +0000
@@ -91,8 +91,8 @@
     def readv(self, relpath, offsets):
         return self._decorated.readv(self._squash_name(relpath), offsets)
 
-    def put(self, relpath, f, mode=None):
-        return self._decorated.put(self._squash_name(relpath), f, mode)
+    def put_file(self, relpath, f, mode=None):
+        return self._decorated.put_file(self._squash_name(relpath), f, mode)
 
 
 class FakeVFATServer(DecoratorServer):

=== modified file 'bzrlib/transport/ftp.py'
--- bzrlib/transport/ftp.py	2006-08-25 22:41:03 +0000
+++ bzrlib/transport/ftp.py	2006-09-05 19:34:34 +0000
@@ -294,7 +294,7 @@
                 self._FTP_instance = None
                 return self.get(relpath, decode, retries+1)
 
-    def put(self, relpath, fp, mode=None, retries=0):
+    def put_file(self, relpath, fp, mode=None, retries=0):
         """Copy the file-like or string object into the location.
 
         :param relpath: Location to put the contents, relative to base.
@@ -333,7 +333,7 @@
             else:
                 warning("FTP temporary error: %s. Retrying.", str(e))
                 self._FTP_instance = None
-                self.put(relpath, fp, mode, retries+1)
+                self.put_file(relpath, fp, mode, retries+1)
         except EOFError:
             if retries > _number_of_retries:
                 raise errors.TransportError("FTP control connection closed during PUT %s."
@@ -342,7 +342,7 @@
                 warning("FTP control connection closed. Trying to reopen.")
                 time.sleep(_sleep_between_retries)
                 self._FTP_instance = None
-                self.put(relpath, fp, mode, retries+1)
+                self.put_file(relpath, fp, mode, retries+1)
 
     def mkdir(self, relpath, mode=None):
         """Create a directory at the given path."""

=== modified file 'bzrlib/transport/http/__init__.py'
--- bzrlib/transport/http/__init__.py	2006-08-31 10:33:01 +0000
+++ bzrlib/transport/http/__init__.py	2006-09-05 19:34:34 +0000
@@ -284,11 +284,11 @@
 
         return combined
 
-    def put(self, relpath, f, mode=None):
-        """Copy the file-like or string object into the location.
+    def put_file(self, relpath, f, mode=None):
+        """Copy the file-like object into the location.
 
         :param relpath: Location to put the contents, relative to base.
-        :param f:       File-like or string object.
+        :param f:       File-like object.
         """
         raise TransportNotPossible('http PUT not supported')
 

=== modified file 'bzrlib/transport/local.py'
--- bzrlib/transport/local.py	2006-08-25 22:19:48 +0000
+++ bzrlib/transport/local.py	2006-09-05 19:34:34 +0000
@@ -26,6 +26,7 @@
 import tempfile
 
 from bzrlib import (
+    atomicfile,
     osutils,
     urlutils,
     )
@@ -130,19 +131,18 @@
         except (IOError, OSError),e:
             self._translate_error(e, path)
 
-    def put(self, relpath, f, mode=None):
-        """Copy the file-like or string object into the location.
+    def put_file(self, relpath, f, mode=None):
+        """Copy the file-like object into the location.
 
         :param relpath: Location to put the contents, relative to base.
         :param f:       File-like or string object.
         """
-        from bzrlib.atomicfile import AtomicFile
 
         path = relpath
         try:
             path = self._abspath(relpath)
             check_legal_path(path)
-            fp = AtomicFile(path, 'wb', new_mode=mode)
+            fp = atomicfile.AtomicFile(path, 'wb', new_mode=mode)
         except (IOError, OSError),e:
             self._translate_error(e, path)
         try:
@@ -151,6 +151,26 @@
         finally:
             fp.close()
 
+    def put_bytes(self, relpath, bytes, mode=None):
+        """Copy the string into the location.
+
+        :param relpath: Location to put the contents, relative to base.
+        :param bytes:   String
+        """
+
+        path = relpath
+        try:
+            path = self._abspath(relpath)
+            check_legal_path(path)
+            fp = atomicfile.AtomicFile(path, 'wb', new_mode=mode)
+        except (IOError, OSError),e:
+            self._translate_error(e, path)
+        try:
+            fp.write(bytes)
+            fp.commit()
+        finally:
+            fp.close()
+
     def iter_files_recursive(self):
         """Iter the relative paths of files in the transports sub-tree."""
         queue = list(self.list_dir(u'.'))

=== modified file 'bzrlib/transport/memory.py'
--- bzrlib/transport/memory.py	2006-08-30 14:37:31 +0000
+++ bzrlib/transport/memory.py	2006-09-05 19:34:34 +0000
@@ -133,8 +133,8 @@
             raise NoSuchFile(relpath)
         return StringIO(self._files[_abspath][0])
 
-    def put(self, relpath, f, mode=None):
-        """See Transport.put()."""
+    def put_file(self, relpath, f, mode=None):
+        """See Transport.put_file()."""
         _abspath = self._abspath(relpath)
         self._check_parent(_abspath)
         self._files[_abspath] = (f.read(), mode)

=== modified file 'bzrlib/transport/readonly.py'
--- bzrlib/transport/readonly.py	2006-07-28 16:05:23 +0000
+++ bzrlib/transport/readonly.py	2006-09-05 19:34:34 +0000
@@ -43,8 +43,12 @@
         """See Transport.delete_tree()."""
         raise TransportNotPossible('readonly transport')
 
-    def put(self, relpath, f, mode=None):
-        """See Transport.put()."""
+    def put_file(self, relpath, f, mode=None):
+        """See Transport.put_file()."""
+        raise TransportNotPossible('readonly transport')
+
+    def put_bytes(self, relpath, bytes, mode=None):
+        """See Transport.put_bytes()."""
         raise TransportNotPossible('readonly transport')
 
     def mkdir(self, relpath, mode=None):

=== modified file 'bzrlib/transport/sftp.py'
--- bzrlib/transport/sftp.py	2006-08-30 14:37:31 +0000
+++ bzrlib/transport/sftp.py	2006-09-05 19:34:34 +0000
@@ -366,12 +366,12 @@
             # on to the next
             cur_coalesced = cur_coalesced_stack.next()
 
-    def put(self, relpath, f, mode=None):
+    def put_file(self, relpath, f, mode=None):
         """
-        Copy the file-like or string object into the location.
+        Copy the file-like object into the location.
 
         :param relpath: Location to put the contents, relative to base.
-        :param f:       File-like or string object.
+        :param f:       File-like object.
         :param mode: The final mode for the file
         """
         final_path = self._remote_path(relpath)

